<?php
/**
 * Zeroerror Lite Theme Customizer
 *
 * @package Zeroerror Lite
 */

/**
 * Add postMessage support for site title and description for the Theme Customizer.
 *
 * @param WP_Customize_Manager $wp_customize Theme Customizer object.
 */
function zeroerror_lite_customize_register( $wp_customize ) {	
	
	function zeroerror_lite_sanitize_dropdown_pages( $page_id, $setting ) {
	  // Ensure $input is an absolute integer.
	  $page_id = absint( $page_id );
	
	  // If $page_id is an ID of a published page, return it; otherwise, return the default.
	  return ( 'publish' == get_post_status( $page_id ) ? $page_id : $setting->default );
	}

	function zeroerror_lite_sanitize_checkbox( $checked ) {
		// Boolean check.
		return ( ( isset( $checked ) && true == $checked ) ? true : false );
	} 
	
	function zeroerror_lite_sanitize_phone_number( $phone ) {
		// sanitize phone
		return preg_replace( '/[^\d+]/', '', $phone );
	} 
		
	$wp_customize->get_setting( 'blogname' )->transport         = 'postMessage';
	$wp_customize->get_setting( 'blogdescription' )->transport  = 'postMessage';	

	$wp_customize->add_setting('color_scheme',array(
			'default'	=> '#8EAE0E',
			'sanitize_callback'	=> 'sanitize_hex_color'
	));
	
	$wp_customize->add_control(
		new WP_Customize_Color_Control($wp_customize,'color_scheme',array(
			'label' => __('Color Scheme','zeroerror-lite'),			
			'description'	=> __('More color options in PRO Version','zeroerror-lite'),
			'section' => 'colors',
			'settings' => 'color_scheme'
		))
	);
	
	// Slider Section		
	$wp_customize->add_section( 'slider_section', array(
            'title' => __('Slider Settings', 'zeroerror-lite'),
            'priority' => null,
             'description'	=> __('Featured Image Size Should be ( 1400x500 ) More slider settings available in PRO Version','zeroerror-lite'),				
       ) );	
	
	$wp_customize->add_setting('page-setting7',array(
			'default' => '0',			
			'capability' => 'edit_theme_options',
			'sanitize_callback'	=> 'zeroerror_lite_sanitize_dropdown_pages'
	));
	
	$wp_customize->add_control('page-setting7',array(
			'type'	=> 'dropdown-pages',
			'label'	=> __('Select page for slide one:','zeroerror-lite'),
			'section'	=> 'slider_section'
	));	
	
	$wp_customize->add_setting('page-setting8',array(
			'default' => '0',			
			'capability' => 'edit_theme_options',
			'sanitize_callback'	=> 'zeroerror_lite_sanitize_dropdown_pages'
	));
	
	$wp_customize->add_control('page-setting8',array(
			'type'	=> 'dropdown-pages',
			'label'	=> __('Select page for slide two:','zeroerror-lite'),
			'section'	=> 'slider_section'
	));	
	
	$wp_customize->add_setting('page-setting9',array(
			'default' => '0',			
			'capability' => 'edit_theme_options',
			'sanitize_callback'	=> 'zeroerror_lite_sanitize_dropdown_pages'
	));
	
	$wp_customize->add_control('page-setting9',array(
			'type'	=> 'dropdown-pages',
			'label'	=> __('Select page for slide three:','zeroerror-lite'),
			'section'	=> 'slider_section'
	));	// Slider Section
	
	
	$wp_customize->add_setting('zeroerror_lite_hdrslidepagebutton',array(
		'default' => null,
		'sanitize_callback' => 'sanitize_text_field'	
	));
	
	$wp_customize->add_control('zeroerror_lite_hdrslidepagebutton',array(	
		'type' => 'text',
		'label' => __('enter slider Read more button name here','zeroerror-lite'),
		'section' => 'slider_section',
		'setting' => 'zeroerror_lite_hdrslidepagebutton'
	)); // header Slider Read More Button Text
	
	
	$wp_customize->add_setting('zeroerror_lite_show_headerslider',array(
		'default' => false,
		'sanitize_callback' => 'zeroerror_lite_sanitize_checkbox',
		'capability' => 'edit_theme_options',
	));	 
	
	$wp_customize->add_control( 'zeroerror_lite_show_headerslider', array(
	    'settings' => 'zeroerror_lite_show_headerslider',
	    'section'   => 'slider_section',
	    'label'     => __('Check To Show This Section','zeroerror-lite'),
	   'type'      => 'checkbox'
	 ));//Show Header Slider Section	
	
	
	
	// Home Three Boxes Section 	
	$wp_customize->add_section('section_second', array(
		'title'	=> __('Homepage Three Boxes Section','zeroerror-lite'),
		'description'	=> __('Select Pages from the dropdown for homepage three boxes section','zeroerror-lite'),
		'priority'	=> null
	));		
	
	$wp_customize->add_setting('page-column1',	array(
			'default' => '0',			
			'capability' => 'edit_theme_options',
			'sanitize_callback' => 'zeroerror_lite_sanitize_dropdown_pages',
		));
 
	$wp_customize->add_control(	'page-column1',array(
			'type' => 'dropdown-pages',
			'label' => __('select page for box1','zeroerror-lite'),
			'section' => 'section_second',
	));		
	
	$wp_customize->add_setting('page-column2',	array(
			'default' => '0',			
			'capability' => 'edit_theme_options',
			'sanitize_callback' => 'zeroerror_lite_sanitize_dropdown_pages',
		));
 
	$wp_customize->add_control(	'page-column2',array(
			'type' => 'dropdown-pages',
			'label' => __('select page for box2','zeroerror-lite'),
			'section' => 'section_second',
	));
	
	$wp_customize->add_setting('page-column3',	array(
			'default' => '0',			
			'capability' => 'edit_theme_options',
			'sanitize_callback' => 'zeroerror_lite_sanitize_dropdown_pages',
		));
 
	$wp_customize->add_control(	'page-column3',array(
			'type' => 'dropdown-pages',
			'label' => __('select page for box3','zeroerror-lite'),
			'section' => 'section_second',
	));	//end three column part
	
	
	$wp_customize->add_setting('zeroerror_lite_show_threebxpage',array(
		'default' => false,
		'sanitize_callback' => 'zeroerror_lite_sanitize_checkbox',
		'capability' => 'edit_theme_options',
	));	 
	
	$wp_customize->add_control( 'zeroerror_lite_show_threebxpage', array(
	    'settings' => 'zeroerror_lite_show_threebxpage',
	    'section'   => 'section_second',
	    'label'     => __('Check To Show This Section','zeroerror-lite'),
	   'type'      => 'checkbox'
	 ));//Show3 box section Section	
	
	
	
	// Home Welcome Section 	
	$wp_customize->add_section('section_first',array(
		'title'	=> __('Homepage Welcome Section','zeroerror-lite'),
		'description'	=> __('Select Page from the dropdown for first section','zeroerror-lite'),
		'priority'	=> null
	));
	
	$wp_customize->add_setting('page-setting1',	array(
			'default' => '0',			
			'capability' => 'edit_theme_options',
			'sanitize_callback' => 'zeroerror_lite_sanitize_dropdown_pages',
		));
 
	$wp_customize->add_control(	'page-setting1',array(
			'type' => 'dropdown-pages',
			'label' => __('select page for welcome section','zeroerror-lite'),
			'section' => 'section_first',
	));	
	
	$wp_customize->add_setting('zeroerror_lite_show_welcomesection',array(
		'default' => false,
		'sanitize_callback' => 'zeroerror_lite_sanitize_checkbox',
		'capability' => 'edit_theme_options',
	));	 
	
	$wp_customize->add_control( 'zeroerror_lite_show_welcomesection', array(
	    'settings' => 'zeroerror_lite_show_welcomesection',
	    'section'   => 'section_first',
	    'label'     => __('Check To Show This Section','zeroerror-lite'),
	   'type'      => 'checkbox'
	 ));//Show Welcome Section	
	
	
	$wp_customize->add_section('social_sec',array(
			'title'	=> __('Social Settings','zeroerror-lite'),				
			'description'	=> __('More social icon available in PRO Version','zeroerror-lite'),		
			'priority'		=> null
	));	
	
	$wp_customize->add_setting('fb_link',array(
			'default' => null,
			'sanitize_callback'	=> 'esc_url_raw'	
	));
	
	$wp_customize->add_control('fb_link',array(
			'label'	=> __('Add facebook link here','zeroerror-lite'),
			'section'	=> 'social_sec',
			'setting'	=> 'fb_link'
	));	
	$wp_customize->add_setting('twitt_link',array(
			'default' => null,
			'sanitize_callback'	=> 'esc_url_raw'
	));
	
	$wp_customize->add_control('twitt_link',array(
			'label'	=> __('Add twitter link here','zeroerror-lite'),
			'section'	=> 'social_sec',
			'setting'	=> 'twitt_link'
	));
	$wp_customize->add_setting('insta_link',array(
			'default' => null,
			'sanitize_callback'	=> 'esc_url_raw'
	));
	$wp_customize->add_control('insta_link',array(
			'label'	=> __('Add instagram link here','zeroerror-lite'),
			'section'	=> 'social_sec',
			'setting'	=> 'insta_link'
	));
	$wp_customize->add_setting('linked_link',array(
			'default' => null,
			'sanitize_callback'	=> 'esc_url_raw'
	));
	$wp_customize->add_control('linked_link',array(
			'label'	=> __('Add linkedin link here','zeroerror-lite'),
			'section'	=> 'social_sec',
			'setting'	=> 'linked_link'
	));
	
	$wp_customize->add_setting('zeroerror_lite_show_social_sec',array(
		'default' => false,
		'sanitize_callback' => 'zeroerror_lite_sanitize_checkbox',
		'capability' => 'edit_theme_options',
	));	 
	
	$wp_customize->add_control( 'zeroerror_lite_show_social_sec', array(
	    'settings' => 'zeroerror_lite_show_social_sec',
	    'section'   => 'social_sec',
	    'label'     => __('Check To Show This Section','zeroerror-lite'),
	   'type'      => 'checkbox'
	 ));//Show Social Section	
	
	
	$wp_customize->add_section('contact_sec',array(
			'title'	=> __('Header Contact Details','zeroerror-lite'),
			'description'	=> __('Add you contact details here','zeroerror-lite'),
			'priority'	=> null
	));	
	
	$wp_customize->add_setting('contact_no',array(
			'default' => null,
			'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('contact_no',array(
			'label'	=> __('Add contact number here.','zeroerror-lite'),
			'section'	=> 'contact_sec',
			'setting'	=> 'contact_no'
	));
	$wp_customize->add_setting('contact_mail',array(
			'default' => null,
			'sanitize_callback' => 'sanitize_email'
	));
	
	$wp_customize->add_control('contact_mail',array(
			'type' => 'email',
			'label'	=> __('Add you email here','zeroerror-lite'),
			'section'	=> 'contact_sec',
			'setting'	=> 'contact_mail'
	));	
	
	$wp_customize->add_setting('zeroerror_lite_show_contact_sec',array(
		'default' => false,
		'sanitize_callback' => 'zeroerror_lite_sanitize_checkbox',
		'capability' => 'edit_theme_options',
	));	 
	
	$wp_customize->add_control( 'zeroerror_lite_show_contact_sec', array(
	    'settings' => 'zeroerror_lite_show_contact_sec',
	    'section'   => 'contact_sec',
	    'label'     => __('Check To Show This Section','zeroerror-lite'),
	   'type'      => 'checkbox'
	 ));//Show Social Section		
	
}
add_action( 'customize_register', 'zeroerror_lite_customize_register' );



function zeroerror_lite_custom_css(){
		?>
        	<style type="text/css"> 
					
					a, .blog_lists h2 a:hover,
					#sidebar ul li a:hover,								
					.sitenav ul li a:hover, .sitenav ul li.current_page_item a,
					.services-wrap .one_third h4:hover,
					.slide_info .slide_more:hover,
					.social-icons a,
					.headertop
					{ color:<?php echo esc_html( get_theme_mod('color_scheme','#8EAE0E')); ?>;}
					 
					
					.pagination ul li .current, .pagination ul li a:hover, 
					#commentform input#submit:hover,					
					.nivo-controlNav a.active,				
					h3.widget-title,	
					nav.pagination .page-numbers.current,			
					.wpcf7 input[type='submit'],
					#footer-wrapper
					
					{ background-color:<?php echo esc_html( get_theme_mod('color_scheme','#8EAE0E')); ?>;}
					
					.sitenav ul li a:hover, .sitenav ul li.current_page_item a,
					.slide_info .slide_more:hover
					{ border-color:<?php echo esc_html( get_theme_mod('color_scheme','#8EAE0E')); ?>;}
					
					.headertop
					{ border-top:2px solid <?php echo esc_html( get_theme_mod('color_scheme','#8EAE0E')); ?>;}
					
					button:focus,
					input[type="button"]:focus,
					input[type="reset"]:focus,
					input[type="submit"]:focus,
					input[type="text"]:focus,
					input[type="email"]:focus,
					input[type="url"]:focus,
					input[type="password"]:focus,
					input[type="search"]:focus,
					input[type="number"]:focus,
					input[type="tel"]:focus,
					input[type="range"]:focus,
					input[type="date"]:focus,
					input[type="month"]:focus,
					input[type="week"]:focus,
					input[type="time"]:focus,
					input[type="datetime"]:focus,
					input[type="datetime-local"]:focus,
					input[type="color"]:focus,
					textarea:focus,
					#templatelayout a:focus
						{ outline:thin dotted <?php echo esc_html( get_theme_mod('color_scheme','#8EAE0E')); ?>;}	
					
			</style> 
<?php          
}
         
add_action('wp_head','zeroerror_lite_custom_css');	

/**
 * Binds JS handlers to make Theme Customizer preview reload changes asynchronously.
 */
function zeroerror_lite_customize_preview_js() {
	wp_enqueue_script( 'zeroerror_lite_customizer', get_template_directory_uri() . '/js/customize-preview.js', array( 'customize-preview' ), '20130508', true );
}
add_action( 'customize_preview_init', 'zeroerror_lite_customize_preview_js' );


function zeroerror_lite_custom_customize_enqueue() {
	wp_enqueue_script( 'zeroerror-lite-custom-customize', get_template_directory_uri() . '/js/custom.customize.js', array( 'jquery', 'customize-controls' ), false, true );
}
add_action( 'customize_controls_enqueue_scripts', 'zeroerror_lite_custom_customize_enqueue' );